@@ -9,10 +9,15 @@ from pathlib import Path
 def read_file(file: str) -> str:
     """Read a file content
 
-    :param file: path to the file
-    :type file: str
-    :return: A string with the file content
-    :rtype: str
+    Parameters
+    ----------
+    file : str
+        path to the file
+
+    Returns
+    -------
+    str
+        A string with the file content
     """
     with open(file, "r") as file:
         private_key = file.read()
@@ -24,19 +29,23 @@ def file_print(
 ) -> None:
     """Print the content to file
 
-    :param content: Content to be printed
-    :type content:
-    :param file: path to the file
-    :type file: str
-    :param mode: write mode. Can be 'write' or 'append', defaults to "write"
-    :type mode: str, optional
-    :param sep: string inserted between values, defaults to " "
-    :type sep: str, optional
-    :param end: string appended after the last value, defaults to "\n"
-    :type end: str, optional
+    Parameters
+    ----------
+    content : _type_
+        Content to be printed
+    file : str
+        path to the file
+    mode : str, optional
+        Write mode. Can be 'write' or 'append', by default "write"
+    sep : str, optional
+        String inserted between values, by default " "
+    end : str, optional
+        String appended after the last value, by default "\n"
     """
+
     if mode == "write":
         mode = "w"
+
     elif mode == "append":
         mode = "a"
 
@@ -44,11 +53,17 @@ def file_print(
         print(content, file=text_file, sep=sep, end=end, **kwargs)
 
 
-def make_directory(path, parents=True, exist_ok=True):
-    """Creates a dict if it does not exists.
+def make_directory(path: str, parents: bool = True, exist_ok: bool = True) -> None:
+    """Creates a directory if it does not exists.
 
-    :param path: path of new directory
-    :type path: str
+    Parameters
+    ----------
+    path : str
+        Path to new directory
+    parents : bool, optional
+        If parents is True, any missing parents of this path are created as needed, by default True
+    exist_ok : bool, optional
+        If exist_ok is false (the default), FileExistsError is raised if the target directory already exists., by default True
     """
 
     try:
@@ -65,7 +80,14 @@ def make_directory(path, parents=True, exist_ok=True):
         logging.error(err)
 
 
-def remove_file(file_path):
+def remove_file(file_path: str) -> None:
+    """Remove the file from a specified path
+
+    Parameters
+    ----------
+    file_path : str
+        Path to the file
+    """
     if os.path.exists(file_path):
         try:
             os.remove(file_path)
@@ -76,7 +98,14 @@ def remove_file(file_path):
         logging.error(f"File '{file_path}' not found")
 
 
-def remove_empty_directory(folder_path):
+def remove_empty_directory(folder_path: str) -> None:
+    """Remove a directory if it is empty
+
+    Parameters
+    ----------
+    folder_path : str
+        Path to the directory
+    """
     if os.path.exists(folder_path):
         if len(os.listdir(folder_path)) == 0:
             try:
@@ -91,6 +120,14 @@ def remove_empty_directory(folder_path):
 
 
 def remove_directory_recursively(folder_path):
+    """Remove a directory even if it is not empty
+
+    Parameters
+    ----------
+    folder_path : str
+        Path to the directory
+    """
+
     if os.path.exists(folder_path):
         try:
             shutil.rmtree(folder_path)
@@ -100,7 +137,17 @@ def remove_directory_recursively(folder_path):
         logging.error(f"Directory '{folder_path}' not found")
 
 
-def remove_directory(folder_path, recursive=False):
+def remove_directory(folder_path, recursive: bool = False) -> None:
+
+    """Remove a directory with option of recusivity
+
+    Parameters
+    ----------
+    folder_path : str
+        Path to the directory
+    recursive : bool, optional
+        True if remove folder recursively, by default False
+    """
     if recursive:
         remove_directory_recursively(folder_path)
     else:
